/**
 * Copyright (c) 2010-2012 EBMWebsourcing, 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.commons.log;

import static org.junit.Assert.assertEquals;

import java.util.AbstractMap;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map.Entry;
import java.util.Set;

import org.junit.Test;

public class LogDataTest {

    @Test
    public void testPutData() {
        LogData logData = new TestLogData();
        logData.putData("testKey", "testValue");
        assertEquals("testValue",logData.get("testKey"));
    }
    
    @Test(expected = UnsupportedOperationException.class)
    public void testKeySetUnmodifiable() {
        LogData logData = new TestLogData();
        Set<String> keySet = logData.keySet();
        keySet.remove("test");
    }
    
    @Test(expected = UnsupportedOperationException.class)
    public void testEntrySetUnmodifiable() {
        LogData logData = new TestLogData();
        logData.putData("test", "testKey");
        Set<Entry<String, Object>> entrySet = logData.entrySet();
        entrySet.remove(new AbstractMap.SimpleEntry<String, Object>("testKey", "testValue"));
    }

    @Test(expected = UnsupportedOperationException.class)
    public void testValuesUnmodifiable() {
        LogData logData = new TestLogData();
        Collection<Object> values = logData.values();
        values.remove(new Object());
    }

    @Test(expected = UnsupportedOperationException.class)
    public void testPutUnsupported() {
        LogData logData = new TestLogData();
        logData.put("test", "testKey");
    }
    
    @Test(expected = UnsupportedOperationException.class)
    public void testPutAllUnsupported() {
        LogData logData = new TestLogData();
        HashMap<String, Object> map = new HashMap<String, Object>();
        map.put("test", "testKey");
        logData.putAll(map);
    }
    
    @Test(expected = UnsupportedOperationException.class)
    public void testCloneUnsupported() {
        LogData logData = new TestLogData();
        logData.putData("test", "testKey");
        logData.clone();
    }
    
    @Test(expected = UnsupportedOperationException.class)
    public void testClearUnsupported() {
        LogData logData = new TestLogData();
        logData.putData("test", "testKey");
        logData.clear();
    }
    
    @Test(expected = UnsupportedOperationException.class)
    public void testRemoveUnsupported() {
        LogData logData = new TestLogData();
        logData.putData("test", "testKey");
        logData.remove("test");
    }
}
